Index: recipes/naclports.py |
diff --git a/recipes/chromium.py b/recipes/naclports.py |
similarity index 74% |
copy from recipes/chromium.py |
copy to recipes/naclports.py |
index 4eac6bdbb712dbb2b258a5987a27eab7f2c4570a..30a1b343093fc9ce54101ca64a0cf1d0581aa6ae 100644 |
--- a/recipes/chromium.py |
+++ b/recipes/naclports.py |
@@ -1,4 +1,4 @@ |
-# Copyright (c) 2013 The Chromium Authors. All rights reserved. |
+# Copyright (c) 2014 The Chromium Authors. All rights reserved. |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
@@ -9,24 +9,22 @@ import recipe_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class Chromium(recipe_util.Recipe): |
- """Basic Recipe class for Chromium.""" |
+class Naclports(recipe_util.Recipe): |
+ """Basic Recipe class for naclports.""" |
@staticmethod |
def fetch_spec(props): |
- url = 'https://chromium.googlesource.com/chromium/src.git' |
+ url = 'https://chromium.googlesource.com/external/naclports.git' |
solution = { 'name' :'src', |
'url' : url, |
- 'deps_file': '.DEPS.git', |
+ 'deps_file': 'DEPS', |
'managed' : False, |
'custom_deps': {}, |
'safesync_url': '', |
} |
- if props.get('webkit_rev', '') == 'ToT': |
- solution['custom_vars'] = {'webkit_rev': ''} |
spec = { |
'solutions': [solution], |
- 'svn_url': 'svn://svn.chromium.org/chrome', |
+ 'svn_url': 'https://naclports.googlecode.com/svn', |
'svn_branch': 'trunk/src', |
'svn_ref': 'git-svn', |
} |
@@ -51,7 +49,7 @@ class Chromium(recipe_util.Recipe): |
def main(argv=None): |
- return Chromium().handle_args(argv) |
+ return Naclports().handle_args(argv) |
if __name__ == '__main__': |